@@ -19,6 +19,7 @@
  */
 
 #include "mknbi.h"
+#include "nblib.h"
 #include "mgl.h"
 
 
@@ -187,10 +188,7 @@ struct expr *ep;
 		warning("string too long for concatenation, truncating");
 		i = destsize;
 	}
-	if ((cp = malloc(i + 1)) == NULL) {
-		perror(progname);
-		exit(EXIT_MEMORY);
-	}
+	cp = (char *)nbmalloc(i + 1);
 	memset(cp, ep->left->spec.cval.val.c, i);
 	cp[i] = '\0';
 	ep->spec.cval.val.s = cp;
@@ -252,10 +250,7 @@ struct expr *ep;
   }
 
   /* Concatenate both strings */
-  if ((cp = malloc(leftlen + rightlen + 1)) == NULL) {
-	perror(progname);
-	exit(EXIT_MEMORY);
-  }
+  cp = (char *)nbmalloc(leftlen + rightlen + 1);
   strncpy(cp, leftstr, leftlen);
   strncpy(&cp[leftlen], rightstr, rightlen);
   cp[leftlen+rightlen] = '\0';
