@@ -19,6 +19,7 @@
  */
 
 #include "mknbi.h"
+#include "nblib.h"
 #include "mgl.h"
 #include "gencode.h"
 #include "opcodes.h"
@@ -132,12 +133,7 @@ struct meminfo *dp;
   }
 
   /* Get some memory for new push info */
-  if ((pp = (struct pushinfo *)malloc(sizeof(struct pushinfo))) == NULL) {
-	perror(progname);
-	exit(EXIT_MEMORY);
-  }
-  memset(pp, 0, sizeof(struct pushinfo));
-
+  pp = (struct pushinfo *)nbmalloc(sizeof(struct pushinfo));
   if ((regs & PUSH_BX) == PUSH_BX && bx_inuse) {
 	putpush(REG_BX);
 	pp->regspushed |= PUSH_BX;
